@@ -1,7 +1,7 @@
 #ifndef __BTCTL_TYPES_H__
 #define __BTCTL_TYPES_H__
 
-#include <glib/gmacros.h>
+#include <glib.h>
 #include <glib-object.h>
 
 G_BEGIN_DECLS
